Regina Documentation! — regina 1 documentation

# Regina Documentation!

rezina is a scalable, distributed and easy to use system for executing python code in parallel across multiple processors or many machines.

rezina provides a simple way to make parallel programming in python more easier, flexible and scalable and shipped with features like periodically schedule, load balance, fail tolerate and dynamically add tasks .

more docs coming soon.

Contents:

- Installation
  - Downloading and installing from source
- Rezina
- why use rezina?
- Support
- Dependencies
- Installaion
  - Downloading and installing from source
- Quick Guide
  - Start rezina
  - Example cityweather
  - rezina console
- Documentation
- periodically schedule
  - Interval
  - Start time
  - Default value of start_time
- Startup setttings
  - Master
  - Worker
  - Console
  - examples
- run python code with rezina
  - Start master and workers
  - Write python code and put it in workspace
  - Write typology to run this code in parallel
  - Run code with rezina
  - manage typology

# Indices and tables

- Index
- Module Index
- Search Page